@@ -3,7 +3,7 @@ use std::env;
 use cargo::ops::CompileOptions;
 use cargo::ops;
 use cargo::util::important_paths::{find_root_manifest_for_wd};
-use cargo::util::{CliResult, CliError, Config};
+use cargo::util::{CliResult, Config};
 
 #[derive(RustcDecodable)]
 struct Options {
@@ -85,7 +85,6 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
         target_rustc_args: None,
     };
 
-    ops::compile(&root, &opts).map(|_| None).map_err(|err| {
-        CliError::from_boxed(err, 101)
-    })
+    try!(ops::compile(&root, &opts));
+    Ok(None)
 }
