@@ -1,7 +1,7 @@
 use std::env;
 
 use cargo::ops;
-use cargo::util::{CliResult, CliError, Config};
+use cargo::util::{CliResult, Config};
 use cargo::util::important_paths::find_root_manifest_for_wd;
 
 #[derive(RustcDecodable)]
@@ -32,6 +32,6 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
     try!(config.shell().set_color_config(options.flag_color.as_ref().map(|s| &s[..])));
     let root = try!(find_root_manifest_for_wd(options.flag_manifest_path, config.cwd()));
 
-    ops::generate_lockfile(&root, config)
-        .map(|_| None).map_err(|err| CliError::from_boxed(err, 101))
+    try!(ops::generate_lockfile(&root, config));
+    Ok(None)
 }
