@@ -1,5 +1,3 @@
-use std::path::Path;
-
 use cargo::ops;
 use cargo::core::{SourceId, GitReference};
 use cargo::util::{CliResult, Config, ToUrl, human};
@@ -97,6 +95,7 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
         filter: ops::CompileFilter::new(false, &options.flag_bin, &[],
                                         &options.flag_example, &[]),
         target_rustc_args: None,
+        target_rustdoc_args: None,
     };
 
     let source = if let Some(url) = options.flag_git {
@@ -112,7 +111,7 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
         };
         SourceId::for_git(&url, gitref)
     } else if let Some(path) = options.flag_path {
-        try!(SourceId::for_path(Path::new(&path)))
+        try!(SourceId::for_path(&config.cwd().join(path)))
     } else {
         try!(SourceId::for_central(config))
     };
