@@ -1,8 +1,7 @@
 use std::env;
-use std::error::Error;
 
 use cargo::core::{Package, Source};
-use cargo::util::{CliResult, CliError, Config};
+use cargo::util::{CliResult, Config};
 use cargo::util::important_paths::{find_root_manifest_for_wd};
 use cargo::sources::{PathSource};
 
@@ -13,6 +12,8 @@ struct Options {
 }
 
 pub const USAGE: &'static str = "
+Print a JSON representation of a Cargo.toml manifest
+
 Usage:
     cargo read-manifest [options]
     cargo read-manifest -h | --help
@@ -20,7 +21,7 @@ Usage:
 Options:
     -h, --help               Print this message
     -v, --verbose            Use verbose output
-    --manifest-path PATH     Path to the manifest to compile
+    --manifest-path PATH     Path to the manifest
     --color WHEN             Coloring: auto, always, never
 ";
 
@@ -31,13 +32,9 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<Package>>
 
     let root = try!(find_root_manifest_for_wd(options.flag_manifest_path, config.cwd()));
 
-    let mut source = try!(PathSource::for_path(root.parent().unwrap(), config).map_err(|e| {
-        CliError::new(e.description(), 1)
-    }));
+    let mut source = try!(PathSource::for_path(root.parent().unwrap(), config));
+    try!(source.update());
 
-    try!(source.update().map_err(|err| CliError::new(err.description(), 1)));
-
-    source.root_package()
-          .map(|pkg| Some(pkg))
-          .map_err(|err| CliError::from_boxed(err, 1))
+    let pkg = try!(source.root_package());
+    Ok(Some(pkg))
 }
