@@ -1,5 +1,5 @@
 use cargo::ops;
-use cargo::util::{CliResult, CliError, Config};
+use cargo::util::{CliResult, Config};
 
 #[derive(RustcDecodable)]
 struct Options {
@@ -34,7 +34,6 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
         ..
     } = options;
 
-    ops::search(&query, config, host)
-        .map(|_| None)
-        .map_err(|err| CliError::from_boxed(err, 101))
+    try!(ops::search(&query, config, host));
+    Ok(None)
 }
