@@ -28,12 +28,12 @@ use std::path::{Path, PathBuf};
 use std::sync::Arc;
 
 use core::registry::PackageRegistry;
-use core::{Source, SourceId, PackageSet, Package, Target};
+use core::{Source, SourceId, SourceMap, PackageSet, Package, Target};
 use core::{Profile, TargetKind, Profiles};
-use core::resolver::Method;
+use core::resolver::{Method, Resolve};
 use ops::{self, BuildOutput, ExecEngine};
 use util::config::{ConfigValue, Config};
-use util::{CargoResult, internal, human, ChainError, profile};
+use util::{CargoResult, internal, ChainError, profile};
 
 /// Contains information about how a package should be compiled.
 pub struct CompileOptions<'a> {
@@ -57,6 +57,8 @@ pub struct CompileOptions<'a> {
     pub release: bool,
     /// Mode for this compile.
     pub mode: CompileMode,
+    /// Extra arguments to be passed to rustdoc (for main crate and dependencies)
+    pub target_rustdoc_args: Option<&'a [String]>,
     /// The specified target will be compiled with all the available arguments,
     /// note that this only accounts for the *final* invocation of rustc
     pub target_rustc_args: Option<&'a [String]>,
@@ -95,6 +97,48 @@ pub fn compile<'a>(manifest_path: &Path,
     compile_pkg(&package, None, options)
 }
 
+pub fn resolve_dependencies<'a>(root_package: &Package,
+                                config: &'a Config,
+                                source: Option<Box<Source + 'a>>,
+                                features: Vec<String>,
+                                no_default_features: bool)
+                                -> CargoResult<(Vec<Package>, Resolve, SourceMap<'a>)> {
+
+    let override_ids = try!(source_ids_from_config(config, root_package.root()));
+
+    let mut registry = PackageRegistry::new(config);
+
+    if let Some(source) = source {
+        registry.add_preloaded(root_package.package_id().source_id(), source);
+    }
+
+    // First, resolve the root_package's *listed* dependencies, as well as
+    // downloading and updating all remotes and such.
+    let resolve = try!(ops::resolve_pkg(&mut registry, root_package));
+
+    // Second, resolve with precisely what we're doing. Filter out
+    // transitive dependencies if necessary, specify features, handle
+    // overrides, etc.
+    let _p = profile::start("resolving w/ overrides...");
+
+    try!(registry.add_overrides(override_ids));
+
+    let method = Method::Required{
+        dev_deps: true, // TODO: remove this option?
+        features: &features,
+        uses_default_features: !no_default_features,
+    };
+
+    let resolved_with_overrides =
+            try!(ops::resolve_with_previous(&mut registry, root_package,
+                                            method, Some(&resolve), None));
+
+    let packages = try!(ops::get_resolved_packages(&resolved_with_overrides,
+                                                   &mut registry));
+
+    Ok((packages, resolved_with_overrides, registry.move_sources()))
+}
+
 #[allow(deprecated)] // connect => join in 1.3
 pub fn compile_pkg<'a>(root_package: &Package,
                        source: Option<Box<Source + 'a>>,
@@ -103,6 +147,7 @@ pub fn compile_pkg<'a>(root_package: &Package,
     let CompileOptions { config, jobs, target, spec, features,
                          no_default_features, release, mode,
                          ref filter, ref exec_engine,
+                         ref target_rustdoc_args,
                          ref target_rustc_args } = *options;
 
     let target = target.map(|s| s.to_string());
@@ -110,48 +155,13 @@ pub fn compile_pkg<'a>(root_package: &Package,
         s.split(' ')
     }).map(|s| s.to_string()).collect::<Vec<String>>();
 
-    if spec.len() > 0 && (no_default_features || features.len() > 0) {
-        return Err(human("features cannot be modified when the main package \
-                          is not being built"))
-    }
     if jobs == Some(0) {
-        return Err(human("jobs must be at least 1"))
+        bail!("jobs must be at least 1")
     }
 
-    let override_ids = try!(source_ids_from_config(options.config, root_package.root()));
-
     let (packages, resolve_with_overrides, sources) = {
-        let mut registry = PackageRegistry::new(options.config);
-
-        if let Some(source) = source {
-            registry.add_preloaded(root_package.package_id().source_id(), source);
-        }
-
-        // First, resolve the root_package's *listed* dependencies, as well as
-        // downloading and updating all remotes and such.
-        let resolve = try!(ops::resolve_pkg(&mut registry, root_package));
-
-        // Second, resolve with precisely what we're doing. Filter out
-        // transitive dependencies if necessary, specify features, handle
-        // overrides, etc.
-        let _p = profile::start("resolving w/ overrides...");
-
-        try!(registry.add_overrides(override_ids));
-
-        let method = Method::Required{
-            dev_deps: true, // TODO: remove this option?
-            features: &features,
-            uses_default_features: !no_default_features,
-        };
-
-        let resolved_with_overrides =
-                try!(ops::resolve_with_previous(&mut registry, root_package,
-                                                method, Some(&resolve), None));
-
-        let packages = try!(ops::get_resolved_packages(&resolved_with_overrides,
-                                                       &mut registry));
-
-        (packages, resolved_with_overrides, registry.move_sources())
+        try!(resolve_dependencies(root_package, config, source, features,
+                                  no_default_features))
     };
 
     let mut invalid_spec = vec![];
@@ -167,8 +177,8 @@ pub fn compile_pkg<'a>(root_package: &Package,
     };
 
     if spec.len() > 0 && invalid_spec.len() > 0 {
-        return Err(human(format!("could not find package matching spec `{}`",
-                                 invalid_spec.connect(", "))));
+        bail!("could not find package matching spec `{}`",
+              invalid_spec.connect(", "))
     }
 
     let to_builds = packages.iter().filter(|p| pkgids.contains(&p.package_id()))
@@ -178,29 +188,40 @@ pub fn compile_pkg<'a>(root_package: &Package,
     let mut package_targets = Vec::new();
 
     let profiles = root_package.manifest().profiles();
-    match *target_rustc_args {
-        Some(args) => {
-            if to_builds.len() == 1 {
-                let targets = try!(generate_targets(to_builds[0], profiles,
-                                                    mode, filter, release));
-                if targets.len() == 1 {
-                    let (target, profile) = targets[0];
-                    let mut profile = profile.clone();
-                    profile.rustc_args = Some(args.to_vec());
-                    general_targets.push((target, profile));
-                } else {
-                    return Err(human("extra arguments to `rustc` can only be \
-                                      passed to one target, consider \
-                                      filtering\nthe package by passing e.g. \
-                                      `--lib` or `--bin NAME` to specify \
-                                      a single target"))
-
-                }
+    match (*target_rustc_args, *target_rustdoc_args) {
+        (Some(..), _) |
+        (_, Some(..)) if to_builds.len() != 1 => {
+            panic!("`rustc` and `rustdoc` should not accept multiple `-p` flags")
+        }
+        (Some(args), _) => {
+            let targets = try!(generate_targets(to_builds[0], profiles,
+                                                mode, filter, release));
+            if targets.len() == 1 {
+                let (target, profile) = targets[0];
+                let mut profile = profile.clone();
+                profile.rustc_args = Some(args.to_vec());
+                general_targets.push((target, profile));
             } else {
-                panic!("`rustc` should not accept multiple `-p` flags")
+                bail!("extra arguments to `rustc` can only be passed to one \
+                       target, consider filtering\nthe package by passing \
+                       e.g. `--lib` or `--bin NAME` to specify a single target")
             }
         }
-        None => {
+        (None, Some(args)) => {
+            let targets = try!(generate_targets(to_builds[0], profiles,
+                                                mode, filter, release));
+            if targets.len() == 1 {
+                let (target, profile) = targets[0];
+                let mut profile = profile.clone();
+                profile.rustdoc_args = Some(args.to_vec());
+                general_targets.push((target, profile));
+            } else {
+                bail!("extra arguments to `rustdoc` can only be passed to one \
+                       target, consider filtering\nthe package by passing e.g. \
+                       `--lib` or `--bin NAME` to specify a single target")
+            }
+        }
+        (None, None) => {
             for &to_build in to_builds.iter() {
                 let targets = try!(generate_targets(to_build, profiles, mode,
                                                     filter, release));
@@ -332,7 +353,7 @@ fn generate_targets<'a>(pkg: &'a Package,
                 if let Some(t) = pkg.targets().iter().find(|t| t.is_lib()) {
                     targets.push((t, profile));
                 } else {
-                    return Err(human(format!("no library targets found")))
+                    bail!("no library targets found")
                 }
             }
 
@@ -344,9 +365,7 @@ fn generate_targets<'a>(pkg: &'a Package,
                         });
                         let t = match target {
                             Some(t) => t,
-                            None => return Err(human(format!("no {} target \
-                                                              named `{}`",
-                                                             desc, name))),
+                            None => bail!("no {} target named `{}`", desc, name),
                         };
                         debug!("found {} `{}`", desc, name);
                         targets.push((t, profile));
@@ -404,11 +423,9 @@ fn scrape_build_config(config: &Config,
     let cfg_jobs = match try!(config.get_i64("build.jobs")) {
         Some((n, p)) => {
             if n <= 0 {
-                return Err(human(format!("build.jobs must be positive, \
-                                          but found {} in {:?}", n, p)));
+                bail!("build.jobs must be positive, but found {} in {:?}", n, p)
             } else if n >= u32::max_value() as i64 {
-                return Err(human(format!("build.jobs is too large: \
-                                          found {} in {:?}", n, p)));
+                bail!("build.jobs is too large: found {} in {:?}", n, p)
             } else {
                 Some(n as u32)
             }
@@ -450,6 +467,7 @@ fn scrape_target_config(config: &Config, triple: &str)
             library_links: Vec::new(),
             cfgs: Vec::new(),
             metadata: Vec::new(),
+            rerun_if_changed: Vec::new(),
         };
         let key = format!("{}.{}", key, lib_name);
         let table = try!(config.get_table(&key)).unwrap().0;
