@@ -159,10 +159,6 @@ pub fn compile_targets<'a, 'cfg: 'a>(pkg_targets: &'a PackagesToBuild<'a>,
         if pkg == root_pkg {
             cx.compilation.cfgs.extend(output.cfgs.iter().cloned());
         }
-        let any_dylib = output.library_links.iter().any(|l| {
-            !l.starts_with("static=") && !l.starts_with("framework=")
-        });
-        if !any_dylib { continue }
         for dir in output.library_paths.iter() {
             cx.compilation.native_dirs.insert(pkg.clone(), dir.clone());
         }
