@@ -9,7 +9,7 @@ use util::CargoResult;
 /// Resolve all dependencies for the specified `package` using the previous
 /// lockfile as a guide if present.
 ///
-/// This function will also generate a write the result of resolution as a new
+/// This function will also write the result of resolution as a new
 /// lockfile.
 pub fn resolve_pkg(registry: &mut PackageRegistry, package: &Package)
                    -> CargoResult<Resolve> {
@@ -17,7 +17,9 @@ pub fn resolve_pkg(registry: &mut PackageRegistry, package: &Package)
     let resolve = try!(resolve_with_previous(registry, package,
                                              Method::Everything,
                                              prev.as_ref(), None));
-    try!(ops::write_pkg_lockfile(package, &resolve));
+    if package.package_id().source_id().is_path() {
+        try!(ops::write_pkg_lockfile(package, &resolve));
+    }
     Ok(resolve)
 }
 
@@ -37,6 +39,9 @@ pub fn resolve_with_previous<'a>(registry: &mut PackageRegistry,
                                  to_avoid: Option<&HashSet<&'a PackageId>>)
                                  -> CargoResult<Resolve> {
 
+    try!(registry.add_sources(&[package.package_id().source_id()
+                                       .clone()]));
+
     // Here we place an artificial limitation that all non-registry sources
     // cannot be locked at more than one revision. This means that if a git
     // repository provides more than one package, they must all be updated in
@@ -73,7 +78,7 @@ pub fn resolve_with_previous<'a>(registry: &mut PackageRegistry,
             // 2. The specified package's summary will have its dependencies
             //    modified to their precise variants. This will instruct the
             //    first step of the resolution process to not query for ranges
-            //    but rather precise dependency versions.
+            //    but rather for precise dependency versions.
             //
             //    This process must handle altered dependencies, however, as
             //    it's possible for a manifest to change over time to have
@@ -103,7 +108,7 @@ pub fn resolve_with_previous<'a>(registry: &mut PackageRegistry,
         None => summary,
     };
 
-    let mut resolved = try!(resolver::resolve(&summary, method, registry));
+    let mut resolved = try!(resolver::resolve(&summary, &method, registry));
     match previous {
         Some(r) => resolved.copy_metadata(r),
         None => {}
