@@ -11,6 +11,7 @@ use std::path::{Path, PathBuf};
 
 use rustc_serialize::{Encodable,Encoder};
 use toml;
+use core::shell::{Verbosity, ColorConfig};
 use core::{MultiShell, Package};
 use util::{CargoResult, ChainError, Rustc, internal, human, paths};
 
@@ -31,16 +32,11 @@ pub struct Config {
 }
 
 impl Config {
-    pub fn new(shell: MultiShell) -> CargoResult<Config> {
-        let cwd = try!(env::current_dir().chain_error(|| {
-            human("couldn't get the current directory of the process")
-        }));
-
+    pub fn new(shell: MultiShell,
+               cwd: PathBuf,
+               homedir: PathBuf) -> CargoResult<Config> {
         let mut cfg = Config {
-            home_path: try!(homedir(cwd.as_path()).chain_error(|| {
-                human("Cargo couldn't find your home directory. \
-                      This probably means that $HOME was not set.")
-            })),
+            home_path: homedir,
             shell: RefCell::new(shell),
             rustc_info: Rustc::blank(),
             cwd: cwd,
@@ -58,6 +54,18 @@ impl Config {
         Ok(cfg)
     }
 
+    pub fn default() -> CargoResult<Config> {
+        let shell = ::shell(Verbosity::Verbose, ColorConfig::Auto);
+        let cwd = try!(env::current_dir().chain_error(|| {
+            human("couldn't get the current directory of the process")
+        }));
+        let homedir = try!(homedir(&cwd).chain_error(|| {
+            human("Cargo couldn't find your home directory. \
+                  This probably means that $HOME was not set.")
+        }));
+        Config::new(shell, cwd, homedir)
+    }
+
     pub fn home(&self) -> &Path { &self.home_path }
 
     pub fn git_db_path(&self) -> PathBuf {
@@ -132,10 +140,9 @@ impl Config {
                     let idx = key.split('.').take(i)
                                  .fold(0, |n, s| n + s.len()) + i - 1;
                     let key_so_far = &key[..idx];
-                    return Err(human(format!("expected table for configuration \
-                                              key `{}`, but found {} in {}",
-                                             key_so_far, val.desc(),
-                                             path.display())));
+                    bail!("expected table for configuration key `{}`, \
+                           but found {} in {}",
+                          key_so_far, val.desc(), path.display())
                 }
             }
         }
@@ -335,8 +342,8 @@ impl ConfigValue {
                     Ok((key, value))
                 }).collect::<CargoResult<_>>()), path.to_path_buf()))
             }
-            v => return Err(human(format!("found TOML configuration value of \
-                                           unknown type `{}`", v.type_str())))
+            v => bail!("found TOML configuration value of unknown type `{}`",
+                       v.type_str()),
         }
     }
 
