@@ -1,20 +1,21 @@
 pub use self::config::Config;
-pub use self::process_builder::{process, ProcessBuilder};
+pub use self::dependency_queue::Dependency;
+pub use self::dependency_queue::{DependencyQueue, Fresh, Dirty, Freshness};
 pub use self::errors::{CargoResult, CargoError, ChainError, CliResult};
-pub use self::errors::{CliError, ProcessError};
-pub use self::errors::{process_error, internal_error, internal, human};
+pub use self::errors::{CliError, ProcessError, CargoTestError};
 pub use self::errors::{Human, caused_human};
+pub use self::errors::{process_error, internal_error, internal, human};
+pub use self::graph::Graph;
+pub use self::hex::{to_hex, short_hash, hash_u64};
+pub use self::lev_distance::{lev_distance};
 pub use self::paths::{join_paths, path2bytes, bytes2path, dylib_path};
 pub use self::paths::{normalize_path, dylib_path_envvar, without_prefix};
-pub use self::lev_distance::{lev_distance};
-pub use self::hex::{to_hex, short_hash};
-pub use self::dependency_queue::{DependencyQueue, Fresh, Dirty, Freshness};
-pub use self::dependency_queue::Dependency;
-pub use self::graph::Graph;
-pub use self::to_url::ToUrl;
-pub use self::to_semver::ToSemver;
-pub use self::vcs::{GitRepo, HgRepo};
+pub use self::process_builder::{process, ProcessBuilder};
+pub use self::rustc::Rustc;
 pub use self::sha256::Sha256;
+pub use self::to_semver::ToSemver;
+pub use self::to_url::ToUrl;
+pub use self::vcs::{GitRepo, HgRepo};
 
 pub mod config;
 pub mod errors;
@@ -30,4 +31,6 @@ pub mod toml;
 pub mod lev_distance;
 mod dependency_queue;
 mod sha256;
+mod shell_escape;
 mod vcs;
+mod rustc;
