@@ -15,7 +15,7 @@ impl Rustc {
     /// If successful this function returns a description of the compiler along
     /// with a list of its capabilities.
     pub fn new<P: AsRef<Path>>(path: P) -> CargoResult<Rustc> {
-        let mut cmd = try!(util::process(path.as_ref()));
+        let mut cmd = util::process(path.as_ref());
         cmd.arg("-vV");
 
         let mut ret = Rustc::blank();
