@@ -1,8 +1,8 @@
 # When updating snapshots, run this file and pipe it into `src/snapshots.txt`
 import os
-import subprocess
 import sys
 import hashlib
+import download
 
 date = sys.argv[1]
 
@@ -24,10 +24,8 @@ snaps = {
 for platform in sorted(snaps):
     triple = snaps[platform]
     tarball = 'cargo-nightly-' + triple + '.tar.gz'
-    url = 'https://static-rust-lang-org.s3.amazonaws.com/cargo-dist/' + date + '/' + tarball
+    url = 'https://static.rust-lang.org/cargo-dist/' + date + '/' + tarball
     dl_path = "target/dl/" + tarball
-    ret = subprocess.call(["curl", "-f", "-s", "-o", dl_path, url])
-    if ret != 0:
-        raise Exception("failed to fetch url")
+    download.get(url, dl_path, quiet=True)
     h = hashlib.sha1(open(dl_path, 'rb').read()).hexdigest()
     print('  ' + platform + ' ' + h)
