@@ -135,13 +135,9 @@ impl ProjectBuilder {
     }
 
     pub fn process<T: AsRef<OsStr>>(&self, program: T) -> ProcessBuilder {
-        let mut p = process(program);
-        p.cwd(&self.root())
-         .env("HOME", &paths::home())
-         .env_remove("CARGO_HOME")  // make sure we don't pick up an outer one
-         .env_remove("CARGO_TARGET_DIR") // we assume 'target'
-         .env_remove("MSYSTEM");    // assume cmd.exe everywhere on windows
-        return p;
+        let mut p = ::process(program);
+        p.cwd(self.root());
+        return p
     }
 
     pub fn cargo(&self, cmd: &str) -> ProcessBuilder {
@@ -273,11 +269,11 @@ pub struct Execs {
     expect_stdin: Option<String>,
     expect_stderr: Option<String>,
     expect_exit_code: Option<i32>,
-    expect_stdout_contains: Vec<String>
+    expect_stdout_contains: Vec<String>,
+    expect_stderr_contains: Vec<String>,
 }
 
 impl Execs {
-
     pub fn with_stdout<S: ToString>(mut self, expected: S) -> Execs {
         self.expect_stdout = Some(expected.to_string());
         self
@@ -298,6 +294,11 @@ impl Execs {
         self
     }
 
+    pub fn with_stderr_contains<S: ToString>(mut self, expected: S) -> Execs {
+        self.expect_stderr_contains.push(expected.to_string());
+        self
+    }
+
     fn match_output(&self, actual: &Output) -> ham::MatchResult {
         self.match_status(actual)
             .and(self.match_stdout(actual))
@@ -325,6 +326,10 @@ impl Execs {
             try!(self.match_std(Some(expect), &actual.stdout, "stdout",
                                 &actual.stderr, true));
         }
+        for expect in self.expect_stderr_contains.iter() {
+            try!(self.match_std(Some(expect), &actual.stderr, "stderr",
+                                &actual.stdout, true));
+        }
         Ok(())
     }
 
@@ -479,7 +484,8 @@ pub fn execs() -> Execs {
         expect_stderr: None,
         expect_stdin: None,
         expect_exit_code: None,
-        expect_stdout_contains: vec![]
+        expect_stdout_contains: Vec::new(),
+        expect_stderr_contains: Vec::new(),
     }
 }
 
